@@ -281,6 +281,7 @@ public class NetworkStatusEntryImpl implements NetworkStatusEntry {
 
   private void parseMLine(String line, String[] parts)
       throws DescriptorParseException {
+    boolean isValid = true;
     if (this.microdescriptorDigests == null) {
       this.microdescriptorDigests = new HashSet<>();
     }
@@ -292,6 +293,17 @@ public class NetworkStatusEntryImpl implements NetworkStatusEntry {
       ParseHelper.verifyThirtyTwoByteBase64String(line,
           parts[2].substring(7));
       this.microdescriptorDigests.add(parts[2].substring(7));
+      this.supportedConsensusMethods = parts[1];
+      String[] methods = parts[1].split(",", -1);
+      for (String method : methods) {
+        if (method.length() < 1) {
+          isValid = false;
+          break;
+        }
+      }
+    }
+    if (!isValid) {
+      throw new DescriptorParseException("Illegal line '" + line + "'.");
     }
   }
 
@@ -451,4 +463,12 @@ public class NetworkStatusEntryImpl implements NetworkStatusEntry {
   public String getMasterKeyEd25519() {
     return this.masterKeyEd25519;
   }
+
+  private String supportedConsensusMethods;
+
+  @Override
+  public String getSupportedConsensusMethods() {
+    return this.supportedConsensusMethods;
+  }
+
 }
